@@ -28,6 +28,8 @@ while True:
 	"""
 	with open("cmd.py","w") as f:
 		f.write(txt)
+def setup():
+	cre()
+	cre_cmd()
 if __name__ == '__main__':
-    cre()
-    cre_cmd()
+    setup()
